@@ -1,5 +1,8 @@
-blm <- function(f,data,par.init,ineq=NULL,trace=FALSE,tol=1e-6,adaptive=FALSE,...){
+blm <- function(f,data,par.init,ineq=NULL,trace=FALSE,tol=1e-6,augmented=TRUE,warn=-1,...){
 
+       warn.setting <- getOption("warn")
+       options(warn=warn)
+         
        if(missing(data)){
          stop("Dataset not supplied. Data must be given as a dataframe.")
        }
@@ -24,17 +27,17 @@ blm <- function(f,data,par.init,ineq=NULL,trace=FALSE,tol=1e-6,adaptive=FALSE,..
         }
         else{
            par.start <- starting.values.blm(f,data,par.init=par.init)
-       }
+        }
  
       LL <- blm.loglik(f,data)
       score <- blm.dot.loglik(f,data)
 	
 
-      constraints <- blm.constraints(f,data,A=ineq)
+      constraints <- blm.constraints(f,data,ineq.mat=ineq)
       
       process.start = proc.time()
 
-      if(adaptive){
+      if(augmented){
         
         fit <- auglag(par=par.start$par.start,fn=LL,gr=score,										hin=constraints$ineq,hin.jac=constraints$ineq.jac,
                                      control.outer=list(trace=trace,...))
@@ -61,19 +64,32 @@ blm <- function(f,data,par.init,ineq=NULL,trace=FALSE,tol=1e-6,adaptive=FALSE,..
 					  formula = f,
 					  constraints = constraints,
                                           active.constraints = list(),
-					  ineq = constraints$A,
+					  ineq = constraints$ineq.mat,
                                           n.missing = na.rm$missing,
                                           H = matrix(),
                                           V = matrix()
 					  )
 
+          
+       if(augmented){
+          H = -fit$hessian
+          blm.object@active.constraints = check.auglag.blm.active.constraints(blm.object)
+        }
+       else{
           H = hessian.blm(blm.object)
+          blm.object@active.constraints = check.active.constraints(blm.object,tol)
+        }
+
           V = -solve(H)
 
           blm.object@H = H
           blm.object@V = V
-                
-          blm.object@active.constraints = check.active.constraints(blm.object,tol)
-        
-        blm.object
+
+         options(warn=warn.setting)
+
+        if(!augmented&!is.null(blm.object@active.constraints)){
+          warning("\nEstimates at the boundary and augmented Lagrangian not used.\nStandard errors might be inaccurate.",immediate.=TRUE,call.=FALSE)
+         }
+       
+ blm.object
 }
